if(!dojo._hasResource["com.ibm.dnd.ModeledSource"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.dnd.ModeledSource"] = true;
dojo.provide("com.ibm.dnd.ModeledSource");

/*
 * A ModeledSource is a dnd Source which provides dnd operational support to a modeled widget.
 * Can be extended to provide different drop actions, as well as drop zones, depending on the
 * type of data being dragged around.  
 * Examples:
 * 	1) Dragging items of the same type around simply creates drop zones around other objects 
 * 		in a heirarchy or list.  Dropping them reorders those items in the modeled heirarchy.
 *  2) Dragging items of different types onto other items creates drop zones on top of the
 * 		items themselves, representing actions where a certain type of data is applied to a
 * 		different type of data.
 */

dojo.require("com.ibm.dnd.TunedLayoutSource");
dojo.require("com.ibm.dnd.PageAvatar");

if(!dojo.isCopyKey) dojo.isCopyKey = dojo.dnd.getCopyKeyState;

dojo.declare("com.ibm.dnd.ModeledSource",
	com.ibm.dnd.TunedLayoutSource,
	{
		managerOverrides: {
			OFFSET_X: 1,
			OFFSET_Y: 1,
			makeAvatar: function(){
				return new com.ibm.dnd.PageAvatar(this);
			}
		},
		model: null,
		item: null,
		isBidi: false,
		constructor: function(/*DOMNode|String*/node, /*dojo.dnd.__SourceArgs?*/params) {
			if(this.withHandles) {
				dojo.addClass(node, "dndHasHandles");
			}
			
			/* PM31491: fixed isBidi calculation (fixes rtl items being dropped to wrong location) */
			if (typeof(ibmCfg) != "undefined" && ibmCfg.themeConfig){this.isBidi = ibmCfg.themeConfig.isRTL;}
			else if(typeof(ibmConfig) != "undefined"){this.isBidi = ibmConfig.isBidi;}
			else if(typeof(ibmPortalConfig) != "undefined") {this.isBidi = ibmPortalConfig.isRTL;}
		},
		onDrop: function(source, nodes, copy) {
			// summary: Called when a drop action occurs in this container
			var targetWidget = dijit.getEnclosingWidget(this.current),
			nextSibling = null,
			newParentItem = null;
			
			if(dojo.hasClass(this.current, "dojoDndItemChild")){
				newParentItem = targetWidget.item;
			}else{
				newParentItem = targetWidget.getParent().item;

				if(this.current) {
					var afterClass = (this.isBidi && this.horizontal) ? "dojoDndItemBefore" : "dojoDndItemAfter";
					
					if(dojo.hasClass(this.current, afterClass)) {
						targetWidget = targetWidget.getNextSibling();
						while(targetWidget && dojo.hasClass(targetWidget.domNode, "dojoDndItemAnchor")) {
							targetWidget = targetWidget.getNextSibling();
						}
					}
					if(targetWidget) nextSibling = targetWidget.item;
				}
			}
			
			setTimeout(dojo.hitch(this, function() {
				dojo.forEach(nodes, function(node){
					var childWidget = dijit.getEnclosingWidget(node),
						childItem = childWidget.item,
						prevParentItem = childWidget.getParent().item;		
						if(this.checkModelAcceptance(childItem,newParentItem)) this.model.pasteItem(childItem, prevParentItem, newParentItem, copy, nextSibling);
				}, this);
			}), 50);
		},
		checkModelAcceptance: function(childItem,parentItem){
				// stub that is called right before an item is pasted to another location
				// overwite to do more specific checks before moving an item
				return true;
		},
		// mouse event processors
		onMouseMove: function(e){
			// summary: event processor for onmousemove
			// e: Event: mouse event
			if(this.isDragging && this.targetState == "Disabled"){ return; }
			dojo.dnd.Source.superclass.onMouseMove.call(this, e);
			var m = dojo.dnd.manager();
			if(this.isDragging){
				dojo.forEach(this.draggingItems, function(item){
					if(item.popup.isShowingNow){
						dijit.popup.close(item.popup);
						this._removeItemClass(this.current, "Over");
						dojo.removeClass(this.current, "dijitMenuItemHover");
					}
				}, this);
				
				// calculate before/after
				var before = false;
				if(this.current){
					
					if(!this.targetBox || this.targetAnchor != this.current){
						this.targetBox = {
							xy: dojo.coords(this.current, true),
							w: this.current.offsetWidth,
							h: this.current.offsetHeight
						};
					}

					if(this.horizontal){
						//before = (e.pageX - this.targetBox.xy.x) < (this.targetBox.w / 2);
						if((e.pageX - this.targetBox.xy.x) < (this.targetBox.w * 0.25)){
							before = "Before";
						}else if((e.pageX - this.targetBox.xy.x) > (this.targetBox.w * 0.75)){
							before = "After";
						}else{
							before = "Child";
						}
						
					}else{
						//before = (e.pageY - this.targetBox.xy.y) < (this.targetBox.h / 2);
						if((e.pageY - this.targetBox.xy.y) < (this.targetBox.h * 0.25)){
							before = "Before";
						}else if((e.pageY - this.targetBox.xy.y) > (this.targetBox.h * 0.75)){
							before = "After";
						}else{
							before = "Child";
						}
						
					}
				}
				if(this.current != this.targetAnchor || before != this.before){
					this._markTargetAnchor(before);
					m.canDrop(!this.current || m.source != this || !(this.current.id in this.selection));
				}
			}else{
				if(this.mouseDown && this.isSource &&
						(Math.abs(e.pageX - this._lastX) > this.delay || Math.abs(e.pageY - this._lastY) > this.delay)){
					var nodes = this.getSelectedNodes();
					if(nodes.length){
						m.startDrag(this, nodes, this.copyState(dojo.isCopyKey(e), true));
					}
				}
			}
		},
		_markTargetAnchor: function(before){
			// summary: assigns a class to the current target anchor based on "before" status
			// before: Boolean: insert before, if true, after otherwise
			if(this.current == this.targetAnchor && this.before == before){ return; }
			if(this.targetAnchor){
				this._removeItemClass(this.targetAnchor, this.before);
			}
			this.targetAnchor = this.current;
			this.targetBox = null;
			this.before = before;
			if(this.targetAnchor){
				this._addItemClass(this.targetAnchor, this.before);
			}
		},
		_unmarkTargetAnchor: function(){
			// summary: removes a class of the current target anchor based on "before" status
			if(!this.targetAnchor){ return; }
			this._removeItemClass(this.targetAnchor, this.before);
			this.targetAnchor = null;
			this.targetBox = null;
			this.before = true;
		},
		onDndStart: function(source, nodes, copy){
			this.draggingItems = [];
			dojo.forEach(nodes, function(node){
				var widget = dijit.getEnclosingWidget(node);
				if(widget && widget.popup){
					this.draggingItems.push(widget);
					this._removeItemClass(widget.popup, "Over");
					dijit.popup.close(widget.popup);
				}
			}, this);
			
			this.inherited(arguments);
			dojo.addClass(this.node, "isDragging");
		},
		onDndCancel: function(){
			this.inherited(arguments);
			dojo.removeClass(this.node, "isDragging");
		},
		destroy: function() {
			this.inherited(arguments);
			this.model = this.node = this.current = this.item = null;
		}
	}
);

}
