-- Licensed Materials - Property of IBM
-- 5724-M24
-- Copyright IBM Corporation 2011.  All Rights Reserved.
-- US Government Users Restricted Rights - Use, duplication or disclosure
-- restricted by GSA ADP Schedule Contract with IBM Corp.
-- ------------------------------------------------------------------------------------
--
-- Run the script in the sqlcmd command line processor
--
-- USAGE:  sqlcmd -U <userid> -P <password> -e -i migrateBusinessSpaceSchema700.sql
--
-- ------------------------------------------------------------------------------------
USE @DB_NAME@;

DROP TABLE @SCHEMA@.VERSION_INFO;

DROP TABLE @SCHEMA@.CATALOG_CATEGORY_LOD;

DROP TABLE @SCHEMA@.CATALOG_ENTRY_DD;

DROP TABLE @SCHEMA@.CATALOG_LOD;

DROP TABLE @SCHEMA@.CATALOG_ENTRY_LOD;

DROP TABLE @SCHEMA@.CATALOG_ENTRY;

DROP TABLE @SCHEMA@.CATALOG_CATEGORY_INC;

DROP TABLE @SCHEMA@.CATALOG_INC;

DROP TABLE @SCHEMA@.CATALOG_CATEGORY;

DROP TABLE @SCHEMA@.CATALOG;

DROP TABLE @SCHEMA@.PREFERENCE_VALUE;

DROP TABLE @SCHEMA@.PREFERENCE;

DROP TABLE @SCHEMA@.NAV_TREE;

DROP TABLE @SCHEMA@.NAVNODE_LOD;

DROP TABLE @SCHEMA@.NAVNODE_DD;

DROP TABLE @SCHEMA@.NAVNODE;

DROP TABLE @SCHEMA@.ACL;

DROP TABLE @SCHEMA@.COMMUNITY_DEF;

DROP TABLE @SCHEMA@.SPACENODE_LOD;

DROP TABLE @SCHEMA@.SPACENODE_DD;

DROP TABLE @SCHEMA@.SPACENODE;

DROP TABLE @SCHEMA@.TEMPLATENODE_LOD;

DROP TABLE @SCHEMA@.TEMPLATENODE;

DROP TABLE @SCHEMA@.AC_MEMBER;

DROP TABLE @SCHEMA@.AC_ROLE;

DROP TABLE @SCHEMA@.AC_RESOURCE;

DROP TABLE @SCHEMA@.FILESTORE_FILE;

DROP TABLE @SCHEMA@.FILESTORE_PATH;

-- *****************************************************************
--
-- SCHEMA VERSION (100)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.VERSION_INFO(
    OID             NVARCHAR(64) NOT NULL,
    VERSION_MAJOR   INT,
    VERSION_MINOR   INT,
    VERSION_RELEASE INT,
    VERSION_DEV     INT,
    VERSION_TIME    BIGINT,
    DESCRIPTION     NVARCHAR(254),
    CONSTRAINT PK100 PRIMARY KEY (OID)
);

-- *****************************************************************
--
-- ACCOUNT (200)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.ACCOUNT (
    OID         NVARCHAR(64)   NOT NULL,
    EXTERNAL_ID NVARCHAR(450)  NOT NULL,
    CREATED     BIGINT         NOT NULL,
    MODIFIED    BIGINT         NOT NULL,
    STATE       INT DEFAULT 1  NOT NULL,
    CONSTRAINT PK200 PRIMARY KEY (OID)
);

-- *****************************************************************
--
-- CATALOG (300)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.CATALOG (
    OID         NVARCHAR(64)  NOT NULL,
    ACCOUNT_OID NVARCHAR(64)  NOT NULL,
    UNIQUE_NAME NVARCHAR(255) NOT NULL,
    CREATED     BIGINT        NOT NULL,
    MODIFIED    BIGINT        NOT NULL,
    STATE       INT DEFAULT 1 NOT NULL,
    CONSTRAINT PK300 PRIMARY KEY (OID)
);

CREATE TABLE @SCHEMA@.CATALOG_LOD (
    RESOURCE_OID NVARCHAR(64)   NOT NULL,
    LOCALE       NVARCHAR(64)   NOT NULL,
    TITLE        NVARCHAR(255)  NOT NULL,
    DESCRIPTION  NVARCHAR(1024) ,
    CONSTRAINT PK301 PRIMARY KEY (RESOURCE_OID, LOCALE),
    CONSTRAINT FK302 FOREIGN KEY (RESOURCE_OID) REFERENCES @SCHEMA@.CATALOG (OID) ON DELETE CASCADE
);

-- *****************************************************************
--
-- CATALOG ENTRY (310)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.CATALOG_ENTRY (
    OID            			NVARCHAR(64)   NOT NULL,
    CATALOG_OID    			NVARCHAR(64)   NOT NULL,
    CATEGORY_OID   			NVARCHAR(64)   NOT NULL,
    DEFINITION_URL 			NVARCHAR(2083) NOT NULL,
    CONTENT_URL    			NVARCHAR(2083) ,
    PREVIEW_URL    			NVARCHAR(2083) ,
    PREVIEW_THUMBNAIL_URL	NVARCHAR(2083) ,
    HELP_URL       			NVARCHAR(2083) ,
    ICON_URL       			NVARCHAR(2083) ,
    HUB_ENTRY_URL  			NVARCHAR(2083) ,
    DEF_URL_TYPE   			INT    ,
    ICON_URL_TYPE  			INT    ,
    CREATED        			BIGINT NOT NULL,
    MODIFIED       			BIGINT NOT NULL,
    STATE          			INT DEFAULT 1 NOT NULL,
    CONSTRAINT PK310 PRIMARY KEY (OID)
);

CREATE TABLE @SCHEMA@.CATALOG_ENTRY_LOD (
    RESOURCE_OID  		NVARCHAR(64)   NOT NULL,
    LOCALE        		NVARCHAR(64)   NOT NULL,
    TITLE         		NVARCHAR(255)  NOT NULL,
    DESCRIPTION   		NVARCHAR(1024) ,
    SHORT_DESCRIPTION   NVARCHAR(255)  ,
    CONSTRAINT PK311 PRIMARY KEY (RESOURCE_OID, LOCALE),
    CONSTRAINT FK311 FOREIGN KEY (RESOURCE_OID) REFERENCES @SCHEMA@.CATALOG_ENTRY (OID) ON DELETE CASCADE
);

CREATE TABLE @SCHEMA@.CATALOG_ENTRY_DD (
    RESOURCE_OID  NVARCHAR(64)   NOT NULL,
    NAME          NVARCHAR(255)  NOT NULL,
    VALUE         NVARCHAR(3000) NOT NULL,
    CONSTRAINT PK312 PRIMARY KEY (RESOURCE_OID, NAME),
    CONSTRAINT FK312 FOREIGN KEY (RESOURCE_OID) REFERENCES @SCHEMA@.CATALOG_ENTRY (OID) ON DELETE CASCADE
);


-- *****************************************************************
--
-- CATALOG CATEGORY (320)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.CATALOG_CATEGORY (
    OID         NVARCHAR(64)  NOT NULL,
    CATALOG_OID NVARCHAR(64)  NOT NULL,
    NAME        NVARCHAR(255) ,
    CREATED     BIGINT        NOT NULL,
    MODIFIED    BIGINT        NOT NULL,
    STATE       INT DEFAULT 1 NOT NULL,
    CONSTRAINT PK320 PRIMARY KEY (OID),
    CONSTRAINT FK320 FOREIGN KEY (CATALOG_OID) REFERENCES @SCHEMA@.CATALOG (OID) ON DELETE CASCADE
);

CREATE TABLE @SCHEMA@.CATALOG_CATEGORY_LOD (
    RESOURCE_OID NVARCHAR(64)   NOT NULL,
    LOCALE       NVARCHAR(64)   NOT NULL,
    TITLE        NVARCHAR(255)  NOT NULL,
    DESCRIPTION  NVARCHAR(1024) ,
    CONSTRAINT PK321 PRIMARY KEY (RESOURCE_OID, LOCALE),
    CONSTRAINT FK321 FOREIGN KEY (RESOURCE_OID) REFERENCES @SCHEMA@.CATALOG_CATEGORY (OID) ON DELETE CASCADE
);


-- *****************************************************************
--
-- CATALOG CATEGORY INCLUDES (330)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.CATALOG_CATEGORY_INC (
    OID          		NVARCHAR(64)   NOT NULL,
    CATALOG_OID  		NVARCHAR(64)   NOT NULL,
    CATEGORY_OID 		NVARCHAR(64)   NOT NULL,
    INCLUDE_CAT  		NVARCHAR(255)  NOT NULL,
    INCLUDE_CATEGORY	NVARCHAR(255)  NOT NULL,
    CONSTRAINT PK330 PRIMARY KEY (OID)
);

-- *****************************************************************
--
-- CATALOG INCLUDES (340)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.CATALOG_INC (
    OID          		NVARCHAR(64)   NOT NULL,
    CATALOG_OID  		NVARCHAR(64)   NOT NULL,
    INCLUDE_CAT  		NVARCHAR(255)  NOT NULL,
    CONSTRAINT PK340 PRIMARY KEY (OID)
);

-- *****************************************************************
--
-- NAVIGATION NODE (500)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.NAVNODE (
    OID            NVARCHAR(64)  NOT NULL,
    OWNER_OID      NVARCHAR(64)  NOT NULL,
    THEME_ID       NVARCHAR(255) NOT NULL,
    THEME_NAME     NVARCHAR(255) NOT NULL,
    CONTENT        VARBINARY(MAX),
    BYTE_COUNT     INT           ,
    IS_ZIPPED      INT DEFAULT 0 NOT NULL,
    COMMUNITY_OID  NVARCHAR(64)  ,
    SPACE_OID      NVARCHAR(64)  ,
    CREATED        BIGINT        NOT NULL,
    MODIFIED       BIGINT        NOT NULL,
    STATE          INT DEFAULT 1 NOT NULL,
    CONSTRAINT PK500 PRIMARY KEY (OID, OWNER_OID)
);

CREATE TABLE @SCHEMA@.NAVNODE_LOD (
    RESOURCE_OID  NVARCHAR(64)   NOT NULL,
    OWNER_OID     NVARCHAR(64)   NOT NULL,
    LOCALE        NVARCHAR(64)   NOT NULL,
    TITLE         NVARCHAR(255)  NOT NULL,
    DESCRIPTION   NVARCHAR(1024) ,
    CONSTRAINT FK500 FOREIGN KEY (RESOURCE_OID,OWNER_OID) REFERENCES @SCHEMA@.NAVNODE (OID,OWNER_OID) ON DELETE CASCADE
);

CREATE TABLE @SCHEMA@.NAVNODE_DD (
    RESOURCE_OID  NVARCHAR(64)    NOT NULL,
    OWNER_OID     NVARCHAR(64)    NOT NULL,
    NAME          NVARCHAR(255)   NOT NULL,
    VALUE         NVARCHAR(3000)  NOT NULL,
    CONSTRAINT PK502 PRIMARY KEY (RESOURCE_OID,OWNER_OID,NAME),
    CONSTRAINT FK502 FOREIGN KEY (RESOURCE_OID,OWNER_OID) REFERENCES @SCHEMA@.NAVNODE (OID,OWNER_OID) ON DELETE CASCADE
);

-- *****************************************************************
--
-- NAVIGATION TREE (510)
--
-- *****************************************************************

CREATE TABLE @SCHEMA@.NAV_TREE (
    OWNER_OID    NVARCHAR(64)   NOT NULL,
    PAGE_OID     NVARCHAR(64)   NOT NULL,
    PARENT_OID   NVARCHAR(64)   NOT NULL,
    ORDINAL      INT  DEFAULT 1 ,
    IS_VIRTUAL   INT  DEFAULT 0 ,
    CONSTRAINT PK510 PRIMARY KEY (OWNER_OID, PAGE_OID)
);

-- *****************************************************************
--
-- ACCESS CONTROL (600)
--
-- *****************************************************************

CREATE TABLE @SCHEMA@.COMMUNITY_DEF (
    OID            NVARCHAR(64)  NOT NULL,
    OWNER_UID      NVARCHAR(64)  NOT NULL,
    RESOURCE_OID   NVARCHAR(64)  NOT NULL,
    RESOURCE_TYPE  NVARCHAR(32)  NOT NULL,
    CREATED        BIGINT        NOT NULL,
    MODIFIED       BIGINT        NOT NULL,
    STATE          INT DEFAULT 1 NOT NULL,
    CONSTRAINT PK600 PRIMARY KEY( OID )
);
-- UNIQUE CONSTRAINT
ALTER TABLE @SCHEMA@.COMMUNITY_DEF ADD CONSTRAINT UQ600 UNIQUE (OID,RESOURCE_OID);

CREATE TABLE @SCHEMA@.ACL (
    COMMUNITY_OID     NVARCHAR(64)  NOT NULL,
    PARTICIPANT_UID   NVARCHAR(64)  NOT NULL,
    PARTICIPANT_TYPE  INT           NOT NULL,
    PERMISSIONS       NVARCHAR(255) NOT NULL,
    CREATED           BIGINT        NOT NULL,
    MODIFIED          BIGINT        NOT NULL,
    STATE             INT DEFAULT 1 NOT NULL,
    CONSTRAINT PK610 PRIMARY KEY (COMMUNITY_OID,PARTICIPANT_UID),
    CONSTRAINT FK611 FOREIGN KEY (COMMUNITY_OID) REFERENCES @SCHEMA@.COMMUNITY_DEF (OID) ON DELETE CASCADE
);

-- *****************************************************************
--
-- SPACES (700)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.SPACENODE (
    OID            NVARCHAR(64)        NOT NULL,
    OWNER_OID      NVARCHAR(64)        NOT NULL,
    ROOTNAV_OID    NVARCHAR(64)        ,
    TEMPLATE_OID   NVARCHAR(64)        ,
    CREATED        BIGINT              NOT NULL,
    MODIFIED       BIGINT              NOT NULL,
    STATE          INT DEFAULT 1       NOT NULL,
    CONSTRAINT PK700 PRIMARY KEY (OID, OWNER_OID)
);

CREATE TABLE @SCHEMA@.SPACENODE_LOD (
    RESOURCE_OID  NVARCHAR(64)    NOT NULL,
    OWNER_OID     NVARCHAR(64)    NOT NULL,
    LOCALE        NVARCHAR(64)    NOT NULL,
    TITLE         NVARCHAR(255)   NOT NULL,
    DESCRIPTION   NVARCHAR(1024)          ,
    CONSTRAINT PK701 PRIMARY KEY (RESOURCE_OID,OWNER_OID,LOCALE),
    CONSTRAINT FK701 FOREIGN KEY (RESOURCE_OID,OWNER_OID) REFERENCES @SCHEMA@.SPACENODE (OID,OWNER_OID) ON DELETE CASCADE
);

CREATE TABLE @SCHEMA@.SPACENODE_DD (
    RESOURCE_OID  NVARCHAR(64)    NOT NULL,
    OWNER_OID     NVARCHAR(64)    NOT NULL,
    NAME          NVARCHAR(255)   NOT NULL,
    VALUE         NVARCHAR(3000)  NOT NULL,
    CONSTRAINT PK702 PRIMARY KEY (RESOURCE_OID,OWNER_OID,NAME),
    CONSTRAINT FK702 FOREIGN KEY (RESOURCE_OID,OWNER_OID) REFERENCES @SCHEMA@.SPACENODE (OID,OWNER_OID) ON DELETE CASCADE
);

-- *****************************************************************
--
-- TEMPLATES (800)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.TEMPLATENODE (
    OID            NVARCHAR(64)        NOT NULL,
    OWNER_OID      NVARCHAR(64)        ,
    CONTENT        VARBINARY(MAX)      ,
    BYTE_COUNT     INT                 ,
    TEMPLATE_TYPE  NVARCHAR(64)        ,
    CREATED        BIGINT              NOT NULL,
    MODIFIED       BIGINT              NOT NULL,
    STATE          INT DEFAULT 1       NOT NULL,
    CONSTRAINT PK800 PRIMARY KEY (OID)
);

CREATE TABLE @SCHEMA@.TEMPLATENODE_LOD (
    RESOURCE_OID  NVARCHAR(64)    NOT NULL,
    LOCALE        NVARCHAR(64)    NOT NULL,
    TITLE         NVARCHAR(255)   NOT NULL,
    DESCRIPTION   NVARCHAR(1024)          ,
    CONSTRAINT PK801 PRIMARY KEY (RESOURCE_OID,LOCALE),
    CONSTRAINT FK801 FOREIGN KEY (RESOURCE_OID) REFERENCES @SCHEMA@.TEMPLATENODE (OID) ON DELETE CASCADE
);

-- *****************************************************************
--
-- ACCESS CONTROL RESOURCES (900)
--
-- *****************************************************************

CREATE TABLE @SCHEMA@.AC_RESOURCE (
    OID            NVARCHAR(64)       NOT NULL,
    OWNER_UID      NVARCHAR(64)       NOT NULL,
    RESOURCE_OID   NVARCHAR(64)       NOT NULL,
    RESOURCE_TYPE  NVARCHAR(32)       NOT NULL,
    ROLE_BLOCKS    NVARCHAR(1024)             ,
    CREATED        BIGINT             NOT NULL,
    MODIFIED       BIGINT             NOT NULL,
    STATE          INT DEFAULT 1      NOT NULL,
    CONSTRAINT PK900 PRIMARY KEY( RESOURCE_OID )
);

CREATE TABLE @SCHEMA@.AC_ROLE (
    AC_RESOURCE_OID   NVARCHAR(64)       NOT NULL,
    ROLE_OID          NVARCHAR(64)       NOT NULL,
    ROLE_NAME         NVARCHAR(1024)     NOT NULL,
    ROLE_TYPE         NVARCHAR(1024)             ,
    CREATED           BIGINT             NOT NULL,
    MODIFIED          BIGINT             NOT NULL,
    STATE             INT DEFAULT 1      NOT NULL,
    CONSTRAINT PK910 PRIMARY KEY( ROLE_OID ),
    CONSTRAINT FK911 FOREIGN KEY (AC_RESOURCE_OID) REFERENCES @SCHEMA@.AC_RESOURCE (RESOURCE_OID) ON DELETE CASCADE
);

CREATE TABLE @SCHEMA@.AC_MEMBER (
    ROLE_OID          NVARCHAR(64)       NOT NULL,
    MEMBER_UID        NVARCHAR(64)       NOT NULL,
    MEMBER_TYPE       INT                NOT NULL,
    CONSTRAINT PK920 PRIMARY KEY (ROLE_OID,MEMBER_UID),
    CONSTRAINT FK921 FOREIGN KEY (ROLE_OID) REFERENCES @SCHEMA@.AC_ROLE (ROLE_OID) ON DELETE CASCADE
);

-- *****************************************************************
--
-- FILESTORE (1000)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.FILESTORE_PATH (
    OID         NVARCHAR(64)           NOT NULL,
    PARENT_OID  NVARCHAR(64)           NOT NULL,
    NAME        NVARCHAR(255)          NOT NULL,
    PATH        NVARCHAR(255)          NOT NULL,
    LOCKED      NVARCHAR(64)           , 
    OWNER       NVARCHAR(64)           ,             
    CREATED     BIGINT                 NOT NULL,
    MODIFIED    BIGINT                 NOT NULL,
    COLL_TYPE   INT DEFAULT 1          NOT NULL,
    CONSTRAINT PK1010 PRIMARY KEY (OID)
);

CREATE TABLE @SCHEMA@.FILESTORE_FILE (
    OID         NVARCHAR(64)           NOT NULL,           
    F_SIZE      INT                    NOT NULL,
    CONTENT     VARBINARY(MAX)
    CONSTRAINT PK1000 PRIMARY KEY (OID),
    CONSTRAINT FK1001 FOREIGN KEY (OID) REFERENCES @SCHEMA@.FILESTORE_PATH (OID) ON DELETE CASCADE
);

-- *****************************************************************
--
-- LAYOUT NODE (1200)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.LAYOUTNODE (
    OID            NVARCHAR(64)        NOT NULL,
    PAGE_OID       NVARCHAR(64)        NOT NULL,
    SKIN_OID       NVARCHAR(255)               ,
    NODE_TYPE      INT DEFAULT 1       NOT NULL,
    CREATED        BIGINT              NOT NULL,
    MODIFIED       BIGINT              NOT NULL,
    CONSTRAINT PK1200 PRIMARY KEY (OID, PAGE_OID)
);

CREATE TABLE @SCHEMA@.LAYOUTNODE_DD (
    PAGE_OID      NVARCHAR(64)    NOT NULL,
    RESOURCE_OID  NVARCHAR(64)    NOT NULL,
    NAME          NVARCHAR(255)   NOT NULL,
    VALUE         NVARCHAR(3000)  NOT NULL,
    CONSTRAINT PK1202 PRIMARY KEY (RESOURCE_OID,PAGE_OID,NAME),
    CONSTRAINT FK1202 FOREIGN KEY (RESOURCE_OID,PAGE_OID) REFERENCES @SCHEMA@.LAYOUTNODE (OID,PAGE_OID) ON DELETE CASCADE
);

-- *****************************************************************
--
-- LAYOUT TREE (1210)
--
-- *****************************************************************

CREATE TABLE @SCHEMA@.LAYOUT_TREE (
    LAYOUTNODE_OID NVARCHAR(64)       NOT NULL,
    PAGE_OID       NVARCHAR(64)       NOT NULL,
    PARENT_OID     NVARCHAR(64)       NOT NULL,
    ORDINAL        INT  DEFAULT 1     ,
    CONSTRAINT PK1210 PRIMARY KEY (LAYOUTNODE_OID,PAGE_OID),
    CONSTRAINT FK1210 FOREIGN KEY (LAYOUTNODE_OID,PAGE_OID) REFERENCES @SCHEMA@.LAYOUTNODE (OID,PAGE_OID) ON DELETE CASCADE
);

-- *****************************************************************
--
-- WIDGET RELATION (1300)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.WIDGET_RELATION (
  OID             NVARCHAR(64)          NOT NULL,
  CONSTRAINT PK1300 PRIMARY KEY (OID)
);

-- *****************************************************************
--
-- WIDGET DEFINITION (1310)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.WIDGET_DEFINITION (
  OID             NVARCHAR(64)          NOT NULL,
  DEFINITION_URL  NVARCHAR(450)         NOT NULL,
  WIDGET_ID       NVARCHAR(255)         NOT NULL,
  WIDGET_TYPE     NVARCHAR(20)          NOT NULL,
  CREATED         BIGINT                NOT NULL,
  MODIFIED        BIGINT                NOT NULL,
  CONSTRAINT PK1310 PRIMARY KEY (OID),
  CONSTRAINT FK1310 FOREIGN KEY (OID) REFERENCES @SCHEMA@.WIDGET_RELATION (OID) ON DELETE CASCADE
);

-- *****************************************************************
--
-- WIDGET INSTANCE (1320)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.WIDGET_INSTANCE (
  OID        NVARCHAR(64)        NOT NULL,
  OWNER_OID  NVARCHAR(64)        ,
  PARENT_OID NVARCHAR(64)        ,
  SANDBOX    INT DEFAULT 0       NOT NULL,
  CREATED    BIGINT NOT NULL     ,
  MODIFIED   BIGINT NOT NULL     ,
  CONSTRAINT PK1320 PRIMARY KEY (OID),
  CONSTRAINT FK1320 FOREIGN KEY (PARENT_OID) REFERENCES @SCHEMA@.WIDGET_INSTANCE (OID),
  CONSTRAINT FK1321 FOREIGN KEY (OID) REFERENCES @SCHEMA@.WIDGET_RELATION (OID) ON DELETE CASCADE
);

-- *****************************************************************
--
-- WIDGET WINDOW (1330)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.WIDGET_WINDOW (
  OID            NVARCHAR(64)        NOT NULL,
  PAGE_OID       NVARCHAR(64)        NOT NULL,
  DEFINITION_OID NVARCHAR(64)        NOT NULL,
  INSTANCE_OID   NVARCHAR(64)        NOT NULL,
  CREATED        BIGINT              NOT NULL,
  MODIFIED       BIGINT              NOT NULL,
  CONSTRAINT PK1330 PRIMARY KEY (OID),
  CONSTRAINT FK1330 FOREIGN KEY (OID, PAGE_OID) REFERENCES @SCHEMA@.LAYOUTNODE (OID, PAGE_OID) ON DELETE CASCADE,
  CONSTRAINT FK1331 FOREIGN KEY (DEFINITION_OID) REFERENCES @SCHEMA@.WIDGET_DEFINITION (OID) ON DELETE CASCADE,
  CONSTRAINT FK1332 FOREIGN KEY (INSTANCE_OID) REFERENCES @SCHEMA@.WIDGET_INSTANCE (OID)
);

-- *****************************************************************
--
-- WIDGET BLOB (1340)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.WIDGET_WIDGETBLOB (
  PARENT_OID       NVARCHAR(64)  NOT NULL,
  CONTENT          VARBINARY(MAX),
  CONSTRAINT PK1340 PRIMARY KEY (PARENT_OID),
  CONSTRAINT FK1340 FOREIGN KEY (PARENT_OID) REFERENCES @SCHEMA@.WIDGET_RELATION (OID) ON DELETE CASCADE
);

-- *****************************************************************
--
-- WIRE (1400)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.WIREITEM (
    OID         NVARCHAR(64)          NOT NULL,
    PAGE_OID    NVARCHAR(64)          NOT NULL,
    CREATED     BIGINT                NOT NULL,
    MODIFIED    BIGINT                NOT NULL,
    S_WIDGET    NVARCHAR(64)          NOT NULL,
    S_EVENT     NVARCHAR(255)         NOT NULL,
    S_EVENTNAME NVARCHAR(255)                 ,
    S_PAGE      NVARCHAR(64)          NOT NULL,
    T_WIDGET    NVARCHAR(64)          NOT NULL,
    T_EVENT     NVARCHAR(255)         NOT NULL,
    T_EVENTNAME NVARCHAR(255)                 ,
    T_PAGE      NVARCHAR(64)          NOT NULL,
    CONSTRAINT PK1400 PRIMARY KEY (OID),
    CONSTRAINT FK1400 FOREIGN KEY (S_WIDGET,PAGE_OID) REFERENCES @SCHEMA@.LAYOUTNODE (OID,PAGE_OID) ON DELETE CASCADE,
    CONSTRAINT FK1401 FOREIGN KEY (T_WIDGET,PAGE_OID) REFERENCES @SCHEMA@.LAYOUTNODE (OID,PAGE_OID)
);

-- *****************************************************************
--
-- LAYOUT_MARKUP_NODE (1500)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.LAYOUT_MARKUP_NODE (
	PAGE_OID    VARCHAR(64)           NOT NULL,
	CREATED     BIGINT                NOT NULL,
	MODIFIED    BIGINT                NOT NULL,
	CONTENT     VARBINARY(MAX),
 	CONSTRAINT PK1500 PRIMARY KEY (PAGE_OID)
);

--*****************************************************************
--
-- Indexing
--
--*****************************************************************
-- Catalog
CREATE INDEX CATACCT      ON @SCHEMA@.CATALOG(ACCOUNT_OID);
CREATE INDEX ENTRYCATGOID ON @SCHEMA@.CATALOG_ENTRY(CATALOG_OID, CATEGORY_OID);
CREATE INDEX CATGCATOID   ON @SCHEMA@.CATALOG_CATEGORY(CATALOG_OID);
CREATE INDEX CATINTCATOID ON @SCHEMA@.CATALOG_INC(CATALOG_OID);

-- Navigation
CREATE INDEX PAGECOMM     ON @SCHEMA@.NAVNODE(COMMUNITY_OID);
CREATE INDEX PAGELODOWNRS ON @SCHEMA@.NAVNODE_LOD(OWNER_OID,RESOURCE_OID);
CREATE INDEX TREEOWPAR    ON @SCHEMA@.NAV_TREE(OWNER_OID,PARENT_OID);

-- Acl
CREATE INDEX COMMOWNPAR ON @SCHEMA@.COMMUNITY_DEF(OWNER_UID);
CREATE INDEX PRTTYUID   ON @SCHEMA@.ACL(PARTICIPANT_TYPE,PARTICIPANT_UID);
CREATE INDEX PRTUID     ON @SCHEMA@.ACL(PARTICIPANT_UID);

-- AC
CREATE INDEX AC_ROLE_RESOURCE ON @SCHEMA@.AC_ROLE(AC_RESOURCE_OID);
CREATE INDEX AC_MEMBER_UID ON @SCHEMA@.AC_MEMBER(MEMBER_UID);
CREATE INDEX AC_MEMBER_MEMBERTYPE ON @SCHEMA@.AC_MEMBER(MEMBER_TYPE ASC);
CREATE INDEX AC_RESOURCE_OWNER ON @SCHEMA@.AC_RESOURCE(OWNER_UID,RESOURCE_OID);

-- FILESTORE_PATH
CREATE INDEX FILESTORE_PATH_1 ON @SCHEMA@.FILESTORE_PATH( PATH );
CREATE INDEX FILESTORE_PATH_2 ON @SCHEMA@.FILESTORE_PATH( PARENT_OID);

-- Layout
CREATE INDEX LAYOUT_TREE_1 ON @SCHEMA@.LAYOUT_TREE(PAGE_OID ASC, PARENT_OID DESC);

-- Account
CREATE INDEX ACCOUNT_1 ON @SCHEMA@.ACCOUNT(EXTERNAL_ID);

-- Widget & Wire
CREATE INDEX WIREITEM_PAGEOID ON @SCHEMA@.WIREITEM(PAGE_OID);
CREATE INDEX WIREITEM_SEVENT ON @SCHEMA@.WIREITEM(S_EVENT);
CREATE INDEX WIREITEM_TEVENT ON @SCHEMA@.WIREITEM(T_EVENT);
CREATE INDEX WIDGETDEFINITION_DEFINITIONURL ON @SCHEMA@.WIDGET_DEFINITION(DEFINITION_URL);
CREATE INDEX WIDGETDEFINITION_WIDGETID ON @SCHEMA@.WIDGET_DEFINITION(WIDGET_ID);
CREATE INDEX WIDGETINSTANCE_PARENTOID ON @SCHEMA@.WIDGET_INSTANCE(PARENT_OID);
CREATE INDEX WIDGETINSTANCE_OWNEROID ON @SCHEMA@.WIDGET_INSTANCE(OWNER_OID);
CREATE INDEX WIDGETWINDOW_INSTANCEOID ON @SCHEMA@.WIDGET_WINDOW(INSTANCE_OID);

--*****************************************************************
--
-- Initialization
--
--*****************************************************************
-- Schema version (leave this here to faciliate version checking)

INSERT INTO @SCHEMA@.VERSION_INFO (OID,VERSION_MAJOR,VERSION_MINOR,VERSION_RELEASE,VERSION_DEV,VERSION_TIME,DESCRIPTION)
VALUES ('458202233263219661970198300000000000',1,0,0,15,0,'Initialization from install script');
